@@ -101,10 +101,10 @@ plot.moveData <- function(x,animals=NULL,compact=FALSE,ask=TRUE,breaks="Sturges"
         xmin <- xmid-(ymax-ymin)/2
       }
 
-      if(length(animalsInd)>6)
-        colors <- rainbow(length(animalsInd)) # to make sure that all colors are distinct
-      else
-        colors <- c(2,3,4,5,6,7)
+      if(length(animalsInd)>7) # to make sure that all colors are distinct
+        colors <- rainbow(length(animalsInd))
+      else # color-blind friendly palette
+        colors <- c("#E69F00", "#56B4E9", "#009E73", "#F0E442", "#0072B2", "#D55E00", "#CC79A7")
 
       ID <- unique(data$ID)[animalsInd[1]]
       x <- data$x[which(data$ID==ID)]
